==> goods-center-api-3.3.3-20251010.052527-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/constant/AppItemNewExtraPropKeyConstant.java <==
package cn.com.duiba.goods.center.api.remoteservice.constant;

/**
 * @Author: fss
 * @Date: 2022/11/10 14
 * @Description:
 */
public class AppItemNewExtraPropKeyConstant {

    /**
     * 商品可以购买的用户标签key
     */
    public static final String GOODS_TAG_CONF = "goodsTagConf";

    /**
     * 商品可以购买的用户标签:配置的白名单信息
     */
    public static final String GOODS_TAG_WHITE_CODE = "cmsHTYHBQGNBMD_liukai";
    /**
     * 汇丰库存告警配置
     */
    public static final String GOODS_STOCK_WARN_CONF = "goodSockWarnConfig";
    /**
     * 展示商品已兑换库存数
     */
    public static final String SHOW_EXCHANGE_NUM = "showExchangeNum";
    /**
     * 展示商品剩余库存数
     */
    public static final String SHOW_REMAIN_NUM = "showRemainNum";

    /**
     * 员工折扣
     */
    public final static String WANDA_CUSTOM_DISCOUNT = "customDiscount";
    /**
     * 分销
     */
    public final static String WANDA_DISTRIBUTION = "distribution";

    /**
     * 分销类型 比如：distributionType_1  员工，distributionType_2 非员工
     */
    public final static String WANDA_DISTRIBUTION_TYPE = "distributionType_";

    /**
     * 万达商品供应商名称
     */
    public final static String WANDA_SUPPLIER_NAME = "wandaSupplierName";
    /**
     *万达商品供应商id
     */
    public final static String WANDA_SUPPLIER_ID = "wandaSupplierId";

    /**
     * 万达商品id
     */
    public final static String WANDA_ITEM_ID = "wandaItemId";

    /**
     * 万达商品税分类id
     */
    public final static String WAND_TAX_CLASSIFY_ID  = "wandaTaxClassifyId";

    /**
     * 运费
     */
    public final static String WANDA_FREIGHT_PRICE = "freightPrice";

    /**
     * 运费模式(0-统一运费 1-运费模版)
     */
    public final static String WANDA_FREIGHT_PRICE_TYPE = "freightPriceType";

    /**
     * 类目ID
     */
    public final static String WANDA_CATEGORY_ID = "categoryId";

    /**
     * 类目名称
     */
    public final static String WANDA_CATEGORY_NAME = "categoryName";

    /**
     * 模版ID
     */
    public final static String WANDA_TEMPLATE_ID = "template_id";

    /**
     * 是否按件计费(0-否 1-是)，默认0
     */
    public final static String WANDA_CHARGE_EACH = "chargeEach";


    /**
     * 万达集采商品
     */
    public final static String WANDA_GROUPBUYING_GOOD = "wandaGroupBuyingGood";
}

==> goods-center-api-3.3.3-20251010.064645-2-sources.jar: cn/com/duiba/goods/center/api/remoteservice/constant/AppItemNewExtraPropKeyConstant.java <==
package cn.com.duiba.goods.center.api.remoteservice.constant;

/**
 * @Author: fss
 * @Date: 2022/11/10 14
 * @Description:
 */
public class AppItemNewExtraPropKeyConstant {

    /**
     * 商品可以购买的用户标签key
     */
    public static final String GOODS_TAG_CONF = "goodsTagConf";

    /**
     * 商品可以购买的用户标签:配置的白名单信息
     */
    public static final String GOODS_TAG_WHITE_CODE = "cmsHTYHBQGNBMD_liukai";
    /**
     * 汇丰库存告警配置
     */
    public static final String GOODS_STOCK_WARN_CONF = "goodSockWarnConfig";
    /**
     * 展示商品已兑换库存数
     */
    public static final String SHOW_EXCHANGE_NUM = "showExchangeNum";
    /**
     * 展示商品剩余库存数
     */
    public static final String SHOW_REMAIN_NUM = "showRemainNum";

    /**
     * 员工折扣
     */
    public final static String WANDA_CUSTOM_DISCOUNT = "customDiscount";
    /**
     * 分销
     */
    public final static String WANDA_DISTRIBUTION = "distribution";

    /**
     * 分销类型 比如：distributionType_1  员工，distributionType_2 非员工
     */
    public final static String WANDA_DISTRIBUTION_TYPE = "distributionType_";

    /**
     * 万达商品供应商名称
     */
    public final static String WANDA_SUPPLIER_NAME = "wandaSupplierName";
    /**
     *万达商品供应商id
     */
    public final static String WANDA_SUPPLIER_ID = "wandaSupplierId";

    /**
     * 万达商品id
     */
    public final static String WANDA_ITEM_ID = "wandaItemId";

    /**
     * 万达商品税分类id
     */
    public final static String WAND_TAX_CLASSIFY_ID  = "wandaTaxClassifyId";

    /**
     * 运费
     */
    public final static String WANDA_FREIGHT_PRICE = "freightPrice";

    /**
     * 运费模式(0-统一运费 1-运费模版)
     */
    public final static String WANDA_FREIGHT_PRICE_TYPE = "freightPriceType";

    /**
     * 类目ID
     */
    public final static String WANDA_CATEGORY_ID = "categoryId";

    /**
     * 类目名称
     */
    public final static String WANDA_CATEGORY_NAME = "categoryName";

    /**
     * 模版ID
     */
    public final static String WANDA_TEMPLATE_ID = "template_id";

    /**
     * 是否按件计费(0-否 1-是)，默认0
     */
    public final static String WANDA_CHARGE_EACH = "chargeEach";


    /**
     * 万达集采商品
     */
    public final static String WANDA_GROUPBUYING_GOOD = "wandaGroupBuyingGood";

    /**
     * 集采价
     */
    public final static String GROUPBUYING_PRICE = "groupBuyingPrice";

    /**
     * 集采最低数量
     */
    public final static String GROUPBUYING_MIN_QUANTITY = "groupBuyingMinQuantity";

    /**
     * 代发价
     */
    public final static String AGENCY_PRICE = "agencyPrice";

    /**
     * 代发最低数量
     */
    public final static String AGENCY_MIN_QUANTITY = "agencyMinQuantity";


}
